'''
date:2020-11-24
author:shiqing
'''

import argparse
import glob
import os

import pandas as pd
import numpy as np 
import cv2
import pickle as pkl
import urllib
import urllib.request
import time


def count_time(func):
    """
    Arguments:
    -----
    """
    def wrapper(*args, **kwargs):
        begin = time.time()
        func(*args, **kwargs)
        end = time.time()
        print("耗时:%s" % (end-begin))

    return wrapper


def download_image(img_path, img_url):
    """
    Arguments:
    --------
    img_path:
    img_url:

    Return:
    --------
    """
    try:
        if not os.path.exists(img_path):
            request = urllib.request.Request(img_url)
            response = urllib.request.urlopen(request)
            get_img = response.read()
            with open(img_path, 'wb') as fp:
                fp.write(get_img)
    except:
        return  0

    return 1


def show_csv(file):
    '''show csv info.

    Parammeters
    -----
    file:input file


    Returns:
    None

    '''
    
    df = pd.read_csv(file)
    print("=============================Headlines=====================")
    print(df.head())

    print("===========================Columns=========================")
    print(df.columns)

    print("============================Shape==========================")
    print(df.shape)



def merge_csv(dst,*files):
    '''merge multi csv files.

    Parameters:
    -------
    dst:output csv file name
    *files:csv files you want to merge

    Returns
    -------
    None


    '''
    try:
        df = pd.concat([pd.read_csv(i) for i in files])
        df.to_csv(dst, index=False) 
    except:
        return 0
    
    return 1


def draw_polygon(im,pts,color):
    '''draw polygon lines for image

    Parameters:
    ----------
    im:image array
    pts:points list [(x1,y1),(x2,y2)...]
    color:line color

    Returns:
    -----------
    im:image after drawing polygon lines
    '''

    h,w,c = im.shape
    for i in range(len(pts)):
        pts[i][0] = int(pts[i][0]*w)
        pts[i][1] = int(pts[i][1]*h)
    pts = np.array(pts)

    cv2.polylines(im,[pts],True,color)

    return im 


def draw_rect(im,pt1,pt2,color):
    '''
    Arguments:
    -----------
    im:image array
    pt1:topleft point
    pt2:bottomright point
    color:(r,g,b)

    Return:
    -----------
    im:
    '''
    h,w,c = im.shape
    pt1[0] = int(pt1[0]*w)
    pt1[1] = int(pt1[1]*h)
    pt2[0] = int(pt2[0]*w)
    pt2[1] = int(pt2[1]*h)
    cv2.rectangle(im,tuple(pt1),tuple(pt2),color,1)

    return im

def get_id2name():
    '''

    Return:
    ----------
    Id2Name:dict{skuid:Name}
    '''
    dir = os.path.dirname(os.path.realpath(__file__))
    with open(os.path.join(dir,"data/pms_metadata.pkl"),"rb") as f:
        Id2Name = pkl.load(f)

    return Id2Name


def filter_df(df,column,values):
    '''
    Arguments:
    -----------
    df:
    column:
    values:

    Return:
    ----------
    values:
    '''
    return df[~df[column].isin(values)]
